==> zfs-linux_2.2.0~rc3.orig.tar.gz: zfs-2.2.0-rc3/module/os/freebsd/zfs/event_os.c <==
/*
 * SPDX-License-Identifier: BSD-2-Clause-FreeBSD
 *
 * Copyright (c) 2022 Rob Wing
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <sys/param.h>
#include <sys/lock.h>
#include <sys/sx.h>
#include <sys/event.h>

#include <sys/freebsd_event.h>

static void
knlist_sx_xlock(void *arg)
{

	sx_xlock((struct sx *)arg);
}

static void
knlist_sx_xunlock(void *arg)
{

	sx_xunlock((struct sx *)arg);
}

static void
knlist_sx_assert_lock(void *arg, int what)
{

	if (what == LA_LOCKED)
		sx_assert((struct sx *)arg, SX_LOCKED);
	else
		sx_assert((struct sx *)arg, SX_UNLOCKED);
}

void
knlist_init_sx(struct knlist *knl, struct sx *lock)
{

	knlist_init(knl, lock, knlist_sx_xlock, knlist_sx_xunlock,
	    knlist_sx_assert_lock);
}

==> zfs-linux_2.2.6.orig.tar.gz: zfs-2.2.6/module/os/freebsd/zfs/event_os.c <==
/*
 * SPDX-License-Identifier: BSD-2-Clause
 *
 * Copyright (c) 2022 Rob Wing
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <sys/param.h>
#include <sys/lock.h>
#include <sys/sx.h>
#include <sys/event.h>

#include <sys/freebsd_event.h>

static void
knlist_sx_xlock(void *arg)
{

	sx_xlock((struct sx *)arg);
}

static void
knlist_sx_xunlock(void *arg)
{

	sx_xunlock((struct sx *)arg);
}

#if __FreeBSD_version >= 1300128
static void
knlist_sx_assert_lock(void *arg, int what)
{

	if (what == LA_LOCKED)
		sx_assert((struct sx *)arg, SX_LOCKED);
	else
		sx_assert((struct sx *)arg, SX_UNLOCKED);
}
#else
static void
knlist_sx_assert_locked(void *arg)
{
	sx_assert((struct sx *)arg, SX_LOCKED);
}
static void
knlist_sx_assert_unlocked(void *arg)
{
	sx_assert((struct sx *)arg, SX_UNLOCKED);
}
#endif

void
knlist_init_sx(struct knlist *knl, struct sx *lock)
{

#if __FreeBSD_version >= 1300128
	knlist_init(knl, lock, knlist_sx_xlock, knlist_sx_xunlock,
	    knlist_sx_assert_lock);
#else
	knlist_init(knl, lock, knlist_sx_xlock, knlist_sx_xunlock,
	    knlist_sx_assert_locked, knlist_sx_assert_unlocked);
#endif
}
